logger property
The LoggerService used for logging command output and interactively prompting users.
Implementation
final LoggerService logger = locator<LoggerService>();
The LoggerService used for logging command output and interactively prompting users.
final LoggerService logger = locator<LoggerService>();