CliException class

Exception thrown when a CLI operation encounters a domain-specific failure.

Implemented types

Constructors

CliException(String message, {dynamic cause, StackTrace? stackTrace, int exitCode = 1})
Constructs a CliException with a message, optional cause, stackTrace, and exitCode.

Properties

cause → dynamic
Underlying error cause, if available.
final
exitCode int
Exit code to return to the OS (defaults to 1).
final
hashCode int
The hash code for this object.
no setterinherited
message String
User-friendly error message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
Optional stack trace of the failure.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited