FileSystemService class abstract

Abstract service providing file system operations.

Implementers

Constructors

FileSystemService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createDirectory(String path) → void
Creates a directory at path.
delete(String path, {bool recursive = false}) → void
Deletes the entity at path, recursively if recursive is true.
exists(String path) bool
Checks whether a file or directory exists at path.
isDirectory(String path) bool
Checks whether path points to an existing directory.
isFile(String path) bool
Checks whether path points to an existing file.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readString(String path) String
Reads contents of file at path as a string.
toString() String
A string representation of this object.
inherited
writeString(String path, String content) → void
Writes content string to file at path.

Operators

operator ==(Object other) bool
The equality operator.
inherited