error abstract method
Logs an error message with optional error object and stackTrace.
Implementation
void error(String message, [dynamic error, StackTrace? stackTrace]);
Logs an error message with optional error object and stackTrace.
void error(String message, [dynamic error, StackTrace? stackTrace]);