targetDirectory property
String
get
targetDirectory
Target directory path for storing agent instructions or configuration files.
Implementation
String get targetDirectory;
Target directory path for storing agent instructions or configuration files.
String get targetDirectory;