GeminiAgent class

AgentProvider implementation for Gemini CLI prompts (.prompts/rules.txt).

Inheritance

Constructors

GeminiAgent()

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Display name of the agent provider.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetDirectory String
Target directory path for storing agent instructions or configuration files.
no setteroverride

Methods

generate(String content) Future<void>
Generates the agent directory if needed and writes the content rule file.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
writeFile(String content) Future<void>
Writes content to the provider's specific configuration file.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited