getVersion method

String? getVersion(
  1. String packageName
)

Returns the recommended version for a given package name. If the package is not in the hardcoded registry, it returns a default constraint (e.g. any) or null, but for this phase we only support known ones or assume 'any'.

Implementation

String? getVersion(String packageName) {
  return defaultPackages[packageName];
}