UpdateService class

Service responsible for checking for updates to the flo_cli package.

Constructors

UpdateService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLatestVersion() Future<String?>
Fetches the latest version of flo_cli from pub.dev. Returns the latest version string, or null if the check fails.
isNewerVersion(String current, String latest) bool
Checks if latest is a newer version than current.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited