YamlConfigService class

YAML file implementation of ConfigService.

Implemented types

Constructors

YamlConfigService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getValue<T>(String key) → T?
Gets a configuration value by key, cast to type T.
override
hasKey(String key) bool
Checks if key exists in the current configuration.
override
load(String path) Future<void>
Loads configuration asynchronously from the file at path.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(String path) Future<void>
Persists current configuration asynchronously to the file at path.
override
setValue<T>(String key, T value) → void
Sets a configuration value for key.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited