commands/add_command library
Classes
- AddBlocSubcommand
- Subcommand for adding a new Bloc component (Bloc, Event, State).
- AddCommand
- Command that adds components or packages to a Flo project.
- AddEntitySubcommand
- Subcommand for adding a new domain entity component.
- AddFeatureSubcommand
- Subcommand for adding a new feature module structure.
- AddModelSubcommand
- Subcommand for adding a new data model component.
- AddPackageSubcommand
-
Subcommand for adding package dependencies to
pubspec.yaml. - AddRepositorySubcommand
- Subcommand for adding a repository interface and implementation component.
- AddScreenSubcommand
- Subcommand for adding a new UI screen widget component.