ConfigService class abstract
Abstract contract for reading, writing, loading, and persisting configuration values.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getValue<
T> (String key) → T? -
Gets a configuration value by
key, cast to typeT. -
hasKey(
String key) → bool -
Checks if
keyexists in the current configuration. -
load(
String path) → Future< void> -
Loads configuration asynchronously from the file at
path. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
String path) → Future< void> -
Persists current configuration asynchronously to the file at
path. -
setValue<
T> (String key, T value) → void -
Sets a configuration value for
key. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited