ProjectConfig class
Model representing a project's generator configuration.
Constructors
-
ProjectConfig({required String projectName, required String org, required List<
String> platforms, required String architecture, required String stateManagement, String? routing, required bool gitInit, required bool generateReadme, List<String> dependencies = const [], Map<String, dynamic> templates = const {}, Map<String, dynamic> agents = const {}, Map<String, dynamic> documentation = const {}}) - Constructs a ProjectConfig model.
- ProjectConfig.fromYamlMap(Map map)
-
Constructs a ProjectConfig instance from a parsed YAML map.
factory
Properties
-
agents
→ Map<
String, dynamic> -
Agent configuration options map.
final
- architecture → String
-
Project architecture pattern (e.g.
Clean Architecture).final -
dependencies
→ List<
String> -
List of dependencies to include.
final
-
documentation
→ Map<
String, dynamic> -
Documentation configuration options map.
final
- generateReadme → bool
-
Whether to generate a README.md file.
final
- gitInit → bool
-
Whether Git initialization should be performed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- org → String
-
Organization prefix (e.g.
com.example).final -
platforms
→ List<
String> -
Target platforms (e.g.
['android', 'ios']).final - projectName → String
-
Name of the project.
final
- routing → String?
-
Optional routing strategy or package.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stateManagement → String
-
State management framework (e.g.
Bloc).final -
templates
→ Map<
String, dynamic> -
Template configuration options map.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
toYamlMap(
) → Map< String, dynamic> - Converts this ProjectConfig into a YAML-serializable Map.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited