AgentProvider class abstract
Abstract interface for AI agent integration providers (Cursor, Claude, Gemini, etc.).
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Display name of the agent provider.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetDirectory → String
-
Target directory path for storing agent instructions or configuration files.
no setter
Methods
-
generate(
String content) → Future< void> -
Generates the agent directory if needed and writes the
contentrule file. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
writeFile(
String content) → Future< void> -
Writes
contentto the provider's specific configuration file.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited