AgentsSetupService class
Service that configures and writes custom AI agent instruction rules to target project directories.
Constructors
-
AgentsSetupService(LoggerService _logger, {List<
AgentProvider> ? providers}) -
Constructs an AgentsSetupService with injected LoggerService and optional custom
providers.
Properties
-
availableProviders
→ List<
AgentProvider> -
Returns an unmodifiable list of all registered AgentProvider instances.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setupAgents(
{List< String> ? agentNames, bool all = false}) → Future<void> -
Prompts or processes selected
agentNames(orall) and generates agent rule files. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited