ComponentGenerator class
Generator service responsible for creating architectural components (Bloc, model, screen, entity, repository, feature).
Constructors
- ComponentGenerator(LoggerService _logger, TemplateEngine _templateEngine)
- Constructs a ComponentGenerator with injected logger and template engine services.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateComponent(
String type, String name, {String? feature}) → Future< void> -
Generates a component of the specified
typeandname, optionally targetting afeature. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited