DependencyEngine class
Engine for manipulating package dependencies in pubspec.yaml.
Constructors
- DependencyEngine({String pubspecPath = 'pubspec.yaml'})
-
Constructs a DependencyEngine with optional custom
pubspecPath.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pubspecPath → String
-
Path to the target
pubspec.yamlfile.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addDependency(
String packageName, String version, {bool isDev = false}) → Future< void> - Adds a dependency to pubspec.yaml
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeDependency(
String packageName, {bool isDev = false}) → Future< void> - Removes a dependency from pubspec.yaml
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited