ProjectWizard class
Interactive wizard for gathering project configuration options from the user.
Constructors
- ProjectWizard({LoggerService? logger})
-
Constructs a ProjectWizard with an optional injected
logger.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runWizard(
{String? initialProjectName, String? initialOrg}) → Future< ProjectConfig> - Runs the interactive CLI wizard and returns a completed ProjectConfig.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited