UpdateService class
Service responsible for checking for updates to the flo_cli package.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getLatestVersion(
) → Future< String?> - Fetches the latest version of flo_cli from pub.dev. Returns the latest version string, or null if the check fails.
-
isNewerVersion(
String current, String latest) → bool -
Checks if
latestis a newer version thancurrent. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited